==> ejc-jltest-impl-3.0.0-20240328.003309-121-sources.jar: com/ejianc/business/jltest/margin/controller/MoneyRefundController.java <==
package com.ejianc.business.jltest.margin.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ejianc.business.jltest.margin.bean.DirectEmployeeDetailEntity;
import com.ejianc.business.jltest.margin.bean.PaymentDetailsEntity;
import com.ejianc.business.jltest.margin.service.IDirectEmployeeDetailService;
import com.ejianc.business.jltest.margin.service.IPaymentDetailsService;
import com.ejianc.business.jltest.orgtest.vo.PlandTreeVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.jltest.margin.bean.MoneyRefundEntity;
import com.ejianc.business.jltest.margin.service.IMoneyRefundService;
import com.ejianc.business.jltest.margin.vo.MoneyRefundVO;

/**
 * 风险金退还
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("moneyRefund")
public class MoneyRefundController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "REFUND_CODE";//此处需要根据实际修改

    @Autowired
    private IMoneyRefundService service;
    @Autowired
    private IDirectEmployeeDetailService detailService;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IPaymentDetailsService paymentDetailsService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MoneyRefundVO> saveOrUpdate(@RequestBody MoneyRefundVO saveOrUpdateVO) {
    	MoneyRefundEntity entity = BeanMapper.map(saveOrUpdateVO, MoneyRefundEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }

        //保存时修改员工明细表hasRecord,使获取明细表参照时过滤该条
        DirectEmployeeDetailEntity employeeDetailEntity = detailService.getById(saveOrUpdateVO.getEmployeeSchedulesId());
        employeeDetailEntity.setHasRecord(2);
        detailService.updateById(employeeDetailEntity);

        entity.setConfirmStatus(1);
    	service.saveOrUpdate(entity, false);
    	MoneyRefundVO vo = BeanMapper.map(entity, MoneyRefundVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MoneyRefundVO> queryDetail(Long id) {
    	MoneyRefundEntity entity = service.selectById(id);
    	if(entity!=null){
            MoneyRefundVO vo = BeanMapper.map(entity, MoneyRefundVO.class);
            return CommonResponse.success("查询详情数据成功！",vo);
        }
        if(entity==null){
            MoneyRefundVO moneyRefundVO = new MoneyRefundVO();
            PaymentDetailsEntity paymentDetailsEntity = paymentDetailsService.selectById(id);
            BeanUtils.copyProperties(paymentDetailsEntity,moneyRefundVO);
           // moneyRefundVO.setDue(paymentDetailsEntity.getPayableAmount());//应缴金额赋值
            //moneyRefundVO.setMobilizeOrg(paymentDetailsEntity.getOrgName());//调动后组织
          //  moneyRefundVO.setCurrentPeriodActualDue(paymentDetailsEntity.getCurrentPaymentAmount());

            Long transferId = paymentDetailsEntity.getTransferId();
            LambdaQueryWrapper<MoneyRefundEntity> wrapper = new LambdaQueryWrapper<>();
            wrapper.eq(MoneyRefundEntity::getId,transferId);
            MoneyRefundEntity one = service.getOne(wrapper);


            moneyRefundVO.setApprovedOutputValue(one.getApprovedOutputValue());
            moneyRefundVO.setIncludeCurrentPeriodActualActualDue(one.getIncludeCurrentPeriodActualActualDue());

            moneyRefundVO.setDue(one.getDue());
            moneyRefundVO.setRefundDate(one.getRefundDate());
            moneyRefundVO.setMobilizeOrgId(one.getMobilizeOrgId());
            moneyRefundVO.setCurrentPeriodActualDue(one.getCurrentPeriodActualDue());

            moneyRefundVO.setIncludeCurrentPeriodActualActualPercentage(one.getIncludeCurrentPeriodActualActualPercentage());
            moneyRefundVO.setMemo(one.getMemo());
//            employeeSchedulesId
            moneyRefundVO.setEmployeeSchedulesId(one.getEmployeeSchedulesId());

            return CommonResponse.success("查询详情数据成功！",moneyRefundVO);
        }
        return CommonResponse.error("系统异常！");

    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MoneyRefundVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (MoneyRefundVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(MoneyRefundVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MoneyRefundVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        String searchText = param.getSearchText();
        List<String> fuzzyFields = param.getFuzzyFields();

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */
        //模糊查询项:申请组织,申请人,单据编号
        if (searchText != null){
            HashMap<String, Parameter> map = new HashMap<>();
            map.put("billCode", new Parameter(QueryParam.LIKE, searchText));
            param.setParams(map);
            IPage<MoneyRefundEntity> page = service.queryPage(param, false);
            if (page.getTotal() == 0){
                map.clear();
                map.put("employeeName", new Parameter(QueryParam.LIKE, searchText));
                param.setParams(map);
                page = service.queryPage(param, false);
                if (page.getTotal() == 0){
                    map.clear();
                    map.put("orgName", new Parameter(QueryParam.LIKE, searchText));
                    param.setParams(map);
                    page = service.queryPage(param, false);
                }
            }
            IPage<MoneyRefundVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
            pageData.setRecords(BeanMapper.mapList(page.getRecords(), MoneyRefundVO.class));
            return CommonResponse.success("查询列表数据成功！", pageData);
        }else {
            IPage<MoneyRefundEntity> page = service.queryPage(param, false);
            IPage<MoneyRefundVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
            pageData.setRecords(BeanMapper.mapList(page.getRecords(), MoneyRefundVO.class));

            return CommonResponse.success("查询列表数据成功！", pageData);
        }
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MoneyRefundEntity> list = service.queryList(param);
        //字段翻译
        List<MoneyRefundVO> resDatas = new ArrayList<>();
        resDatas = BeanMapper.mapList(list, MoneyRefundVO.class);
        for (MoneyRefundVO entity : resDatas) {
            switch (entity.getType()) {
                case 1:
                    entity.setTypeName("退还");
                    break;
                case 2:
                    entity.setTypeName("调动");
                    break;
            }
        }
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", resDatas);
        ExcelExport.getInstance().export("MoneyRefund-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refMoneyRefundData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MoneyRefundVO>> refMoneyRefundData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<MoneyRefundEntity> page = service.queryPage(param,false);
        IPage<MoneyRefundVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MoneyRefundVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-jltest-impl-3.0.0-20240328.021343-126-sources.jar: com/ejianc/business/jltest/margin/controller/MoneyRefundController.java <==
package com.ejianc.business.jltest.margin.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ejianc.business.jltest.margin.bean.DirectEmployeeDetailEntity;
import com.ejianc.business.jltest.margin.bean.PaymentDetailsEntity;
import com.ejianc.business.jltest.margin.service.IDirectEmployeeDetailService;
import com.ejianc.business.jltest.margin.service.IPaymentDetailsService;
import com.ejianc.business.jltest.orgtest.vo.PlandTreeVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.jltest.margin.bean.MoneyRefundEntity;
import com.ejianc.business.jltest.margin.service.IMoneyRefundService;
import com.ejianc.business.jltest.margin.vo.MoneyRefundVO;

/**
 * 风险金退还
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("moneyRefund")
public class MoneyRefundController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "REFUND_CODE";//此处需要根据实际修改

    @Autowired
    private IMoneyRefundService service;
    @Autowired
    private IDirectEmployeeDetailService detailService;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IPaymentDetailsService paymentDetailsService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MoneyRefundVO> saveOrUpdate(@RequestBody MoneyRefundVO saveOrUpdateVO) {
    	MoneyRefundEntity entity = BeanMapper.map(saveOrUpdateVO, MoneyRefundEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }

        //保存时修改员工明细表hasRecord,使获取明细表参照时过滤该条
        DirectEmployeeDetailEntity employeeDetailEntity = detailService.getById(saveOrUpdateVO.getEmployeeSchedulesId());
        employeeDetailEntity.setHasRecord(2);
        detailService.updateById(employeeDetailEntity);

        entity.setConfirmStatus(1);
    	service.saveOrUpdate(entity, false);
    	MoneyRefundVO vo = BeanMapper.map(entity, MoneyRefundVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MoneyRefundVO> queryDetail(Long id) {
    	MoneyRefundEntity entity = service.selectById(id);
    	if(entity!=null){
            MoneyRefundVO vo = BeanMapper.map(entity, MoneyRefundVO.class);
            return CommonResponse.success("查询详情数据成功！",vo);
        }
        if(entity==null){
            MoneyRefundVO moneyRefundVO = new MoneyRefundVO();
            PaymentDetailsEntity paymentDetailsEntity = paymentDetailsService.selectById(id);
            BeanUtils.copyProperties(paymentDetailsEntity,moneyRefundVO);
           // moneyRefundVO.setDue(paymentDetailsEntity.getPayableAmount());//应缴金额赋值
            //moneyRefundVO.setMobilizeOrg(paymentDetailsEntity.getOrgName());//调动后组织
          //  moneyRefundVO.setCurrentPeriodActualDue(paymentDetailsEntity.getCurrentPaymentAmount());

            Long transferId = paymentDetailsEntity.getTransferId();
            LambdaQueryWrapper<MoneyRefundEntity> wrapper = new LambdaQueryWrapper<>();
            wrapper.eq(MoneyRefundEntity::getId,transferId);
            MoneyRefundEntity one = service.getOne(wrapper);


            moneyRefundVO.setApprovedOutputValue(one.getApprovedOutputValue());
            moneyRefundVO.setIncludeCurrentPeriodActualActualDue(one.getIncludeCurrentPeriodActualActualDue());

            moneyRefundVO.setDue(one.getDue());
            moneyRefundVO.setRefundDate(one.getRefundDate());
            moneyRefundVO.setMobilizeOrgId(one.getMobilizeOrgId());
            moneyRefundVO.setCurrentPeriodActualDue(one.getCurrentPeriodActualDue());

            moneyRefundVO.setIncludeCurrentPeriodActualActualPercentage(one.getIncludeCurrentPeriodActualActualPercentage());
            moneyRefundVO.setMemo(one.getMemo());
//            employeeSchedulesId
            moneyRefundVO.setEmployeeSchedulesId(one.getEmployeeSchedulesId());

            return CommonResponse.success("查询详情数据成功！",moneyRefundVO);
        }
        return CommonResponse.error("系统异常！");

    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MoneyRefundVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (MoneyRefundVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(MoneyRefundVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MoneyRefundVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        String searchText = param.getSearchText();
        List<String> fuzzyFields = param.getFuzzyFields();

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */
        HashMap<String, Parameter> map = new HashMap<>();
        //模糊查询项:申请组织,申请人,单据编号
        if (searchText != null){
            map.put("billCode", new Parameter(QueryParam.LIKE, searchText));
            param.setParams(map);
            IPage<MoneyRefundEntity> page = service.queryPage(param, false);
            if (page.getTotal() == 0){
                map.clear();
                map.put("employeeName", new Parameter(QueryParam.LIKE, searchText));
                param.setParams(map);
                page = service.queryPage(param, false);
                if (page.getTotal() == 0){
                    map.clear();
                    map.put("orgName", new Parameter(QueryParam.LIKE, searchText));
                    param.setParams(map);
                    page = service.queryPage(param, false);
                }
            }
            IPage<MoneyRefundVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
            pageData.setRecords(BeanMapper.mapList(page.getRecords(), MoneyRefundVO.class));
            return CommonResponse.success("查询列表数据成功！", pageData);
        }else {
            IPage<MoneyRefundEntity> page = service.queryPage(param, false);
            IPage<MoneyRefundVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
            pageData.setRecords(BeanMapper.mapList(page.getRecords(), MoneyRefundVO.class));

            return CommonResponse.success("查询列表数据成功！", pageData);
        }
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MoneyRefundEntity> list = service.queryList(param);
        //字段翻译
        List<MoneyRefundVO> resDatas = new ArrayList<>();
        resDatas = BeanMapper.mapList(list, MoneyRefundVO.class);
        for (MoneyRefundVO entity : resDatas) {
            switch (entity.getType()) {
                case 1:
                    entity.setTypeName("退还");
                    break;
                case 2:
                    entity.setTypeName("调动");
                    break;
            }
            switch (entity.getConfirmStatus()) {
                case 1:
                    entity.setConfirmStatusName("待确认");
                    break;
                case 2:
                    entity.setConfirmStatusName("确认中");
                    break;
                case 3:
                    entity.setConfirmStatusName("已确认");
                    break;
            }
        }
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", resDatas);
        ExcelExport.getInstance().export("MoneyRefund-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refMoneyRefundData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MoneyRefundVO>> refMoneyRefundData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<MoneyRefundEntity> page = service.queryPage(param,false);
        IPage<MoneyRefundVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MoneyRefundVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
